@@ -18,17 +18,17 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
-#ifndef PATCHREVIEWTEST_H
-#define PATCHREVIEWTEST_H
+#ifndef INTERACTIVEDIFFTEST_H
+#define INTERACTIVEDIFFTEST_H
 
-#include <QtCore/QObject>
+#include <QObject>
 
 #include "../difference.h"
 
 class InteractiveDiffTest : public QObject
 {
     Q_OBJECT
-private slots:
+private Q_SLOTS:
     void testOneLineChange();
     void testSameLine();
     void testLineNumbers_data();
@@ -46,4 +46,4 @@ private:
     void CompareDifferenceStringList(const Diff2::DifferenceStringList& actual, const QStringList& expected);
 };
 
-#endif //  PATCHREVIEWTEST_H
+#endif //  INTERACTIVEDIFFTEST_H
